---
name: Bug 反馈
about: 反馈任何你认为是 bug 需要修复的问题。
title: ''
labels: bug
assignees: ''

---

**描述问题**
请尽量清晰精准地描述你遇到的问题。

**如何复现**
复现问题的步骤。

**预期行为**
你认为修复后的行为应该是怎样的。

**日志**
附上客户端/服务器端在错误发生前后的日志。

**设备和操作系统**
你在用什么设备和操作系统。

**额外信息**
其他你认为有助于解决问题的信息。
